"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var app = require("tns-core-modules/application");
var utils = require("tns-core-modules/utils/utils");
function show(_options) {
    var options = {
        id: _options.id,
        title: _options.title ? _options.title : " ",
        message: _options.message ? _options.message : " ",
        indeterminate: _options.indeterminate != undefined && _options.indeterminate != null ? _options.indeterminate : false,
        progressValue: _options.progressValue != undefined && _options.progressValue != null ? _options.progressValue : 0,
        ongoing: _options.ongoing != undefined && _options.ongoing != null ? _options.ongoing : true
    };
    var builder = this.getBuilder();
    var context = utils.ad.getApplicationContext();
    builder.setContentTitle(options.title)
        .setContentText(options.message)
        .setSmallIcon(context.getApplicationInfo().icon);
    if (options.ongoing) {
        if (options.progressValue >= 100) {
            options.progressValue = 100;
        }
        builder.setOngoing(options.ongoing)
            .setProgress(100, options.progressValue, options.indeterminate);
    }
    this.showNotification(options.id, builder);
    var notification = {
        id: options.id,
        builder: builder
    };
    return notification;
}
exports.show = show;
function update(notification, options) {
    var builder = notification.builder;
    if (options.title != null && options.title != undefined) {
        builder.setContentTitle(options.title);
    }
    if (options.message != null && options.message != undefined) {
        builder.setContentText(options.message);
    }
    if (options.progressValue != null && options.progressValue != undefined) {
        if (options.progressValue >= 100) {
            options.progressValue = 100;
        }
        if (options.indeterminate != null && options.indeterminate != undefined) {
            builder.setProgress(100, options.progressValue, options.indeterminate);
        }
        else {
            builder.setProgress(100, options.progressValue, false);
        }
    }
    if (options.ongoing != null && options.ongoing != undefined) {
        builder.setOngoing(options.ongoing);
    }
    if (options.hideProgressBar) {
        builder.setProgress(0, 0, false);
    }
    this.showNotification(notification.id, builder);
    notification.builder = builder;
    return notification;
}
exports.update = update;
function dismiss(id) {
    this.getNotificationManager().cancel(id);
}
exports.dismiss = dismiss;
function showNotification(id, builder) {
    this.getNotificationManager().notify(id, builder.build());
}
exports.showNotification = showNotification;
function getBuilder() {
    return new android.support.v4.app.NotificationCompat.Builder(this.getActivity());
}
exports.getBuilder = getBuilder;
function getActivity() {
    return app.android.startActivity || app.android.foregroundActivity;
}
exports.getActivity = getActivity;
function getNotificationManager() {
    var context = utils.ad.getApplicationContext();
    return context.getSystemService(android.content.Context.NOTIFICATION_SERVICE);
}
exports.getNotificationManager = getNotificationManager;
//# sourceMappingURL=progress-notification.android.js.map